==> jooq-meta-3.18.6-sources.jar: org/jooq/meta/DefaultJavaTypeResolver.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: https://www.jooq.org/legal/licensing
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.meta;

final class DefaultJavaTypeResolver implements JavaTypeResolver {
    // [#10553] TODO: This was introduced as a dummy implementation
    //          to make [#10534] work. jOOQ-meta should not have any
    //          such implementation
    @Override
    public String resolve(DataTypeDefinition type) {
        return "java.lang.Object";
    }

    @Override
    public String ref(Class<?> type) {
        return type.getName();
    }

    @Override
    public String ref(String type) {
        return type;
    }

    @Override
    public String classLiteral(String type) {
        return type + ".class";
    }

    @Override
    public String constructorCall(String type) {
        return "new " + type;
    }
}

==> jooq-meta-3.19.6-sources.jar: org/jooq/meta/DefaultJavaTypeResolver.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Other licenses:
 * -----------------------------------------------------------------------------
 * Commercial licenses for this work are available. These replace the above
 * ASL 2.0 and offer limited warranties, support, maintenance, and commercial
 * database integrations.
 *
 * For more information, please visit: https://www.jooq.org/legal/licensing
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 *
 */
package org.jooq.meta;

import java.util.function.Supplier;

import org.jooq.Name;

final class DefaultJavaTypeResolver implements JavaTypeResolver {
    // [#10553] TODO: This was introduced as a dummy implementation
    //          to make [#10534] work. jOOQ-meta should not have any
    //          such implementation
    @Override
    public String resolve(DataTypeDefinition type) {
        return "java.lang.Object";
    }

    @Override
    public String resolve(Name type) {
        return "java.lang.Object";
    }

    @Override
    public String ref(Class<?> type) {
        return type.getName();
    }

    @Override
    public String ref(String type) {
        return type;
    }

    @Override
    public String classLiteral(String type) {
        return type + ".class";
    }

    @Override
    public String constructorCall(String type) {
        return "new " + type;
    }

    @Override
    public <T> T resolveDefinedType(Supplier<T> supplier) {
        return supplier.get();
    }
}
